EXPORTS
	_ZNK7CommsFW19TCFSubModuleAddressneERKS0_ @ 1 NONAME ; CommsFW::TCFSubModuleAddress::operator!=(CommsFW::TCFSubModuleAddress const&) const
	_ZN7CommsFW23CCFModuleChannelHandler13CFMessageBindERKNS_10TCFBindMsgE @ 2 NONAME ; CommsFW::CCFModuleChannelHandler::CFMessageBind(CommsFW::TCFBindMsg const&)
	_ZN7CommsFW23CCFModuleChannelHandler17CFMessageDiscoverERKNS_14TCFDiscoverMsgE @ 3 NONAME ; CommsFW::CCFModuleChannelHandler::CFMessageDiscover(CommsFW::TCFDiscoverMsg const&)
	_ZN7CommsFW23CCFModuleChannelHandler17CFMessageShutdownERKNS_14TCFShutdownMsgE @ 4 NONAME ; CommsFW::CCFModuleChannelHandler::CFMessageShutdown(CommsFW::TCFShutdownMsg const&)
	_ZN7CommsFW23CCFModuleChannelHandler15CFMessageUnbindERKNS_12TCFUnbindMsgE @ 5 NONAME ; CommsFW::CCFModuleChannelHandler::CFMessageUnbind(CommsFW::TCFUnbindMsg const&)
	_ZN7CommsFW23CCFModuleChannelHandler16CFMessageUnknownERKNS_10TCFMessageE @ 6 NONAME ; CommsFW::CCFModuleChannelHandler::CFMessageUnknown(CommsFW::TCFMessage const&)
	_ZN7CommsFW17RCFChannelRawBase19CancelDataAvailableEP13RMsgQueueBase @ 7 NONAME ; CommsFW::RCFChannelRawBase::CancelDataAvailable(RMsgQueueBase*)
	_ZN7CommsFW21CCFChannelPairRawBase19CancelDataAvailableEv @ 8 NONAME ; CommsFW::CCFChannelPairRawBase::CancelDataAvailable(void)
	_ZN7CommsFW17RCFChannelRawBase20CancelSpaceAvailableEiP13RMsgQueueBase @ 9 NONAME ; CommsFW::RCFChannelRawBase::CancelSpaceAvailable(int, RMsgQueueBase*)
	_ZN7CommsFW21CCFChannelPairRawBase20CancelSpaceAvailableEi @ 10 NONAME ; CommsFW::CCFChannelPairRawBase::CancelSpaceAvailable(int)
	_ZN7CommsFW21CCFChannelPairRawBase15CloseGracefullyEi @ 11 NONAME ; CommsFW::CCFChannelPairRawBase::CloseGracefully(int)
	_ZN7CommsFW21CCFChannelPairRawBase18CloseNonGracefullyEv @ 12 NONAME ; CommsFW::CCFChannelPairRawBase::CloseNonGracefully(void)
	_ZN7CommsFW17RCFChannelRawBase5CloseEP13RMsgQueueBasei @ 13 NONAME ; CommsFW::RCFChannelRawBase::Close(RMsgQueueBase*, int)
	_ZN7CommsFW23CCFModuleChannelHandler10ConstructLERNS_14RCFChannelBaseINS_10TCFMessageELi1EE13TMsgQueuesTAGES5_ @ 14 NONAME ; CommsFW::CCFModuleChannelHandler::ConstructL(CommsFW::RCFChannelBase<CommsFW::TCFMessage, (int)1>::TMsgQueuesTAG&, CommsFW::RCFChannelBase<CommsFW::TCFMessage,(int)1>::TMsgQueuesTAG&)
	_ZN7CommsFW21CCFChannelPairRawBase10CreateRecvEPK13RMsgQueueBase10TOwnerType @ 15 NONAME ; CommsFW::CCFChannelPairRawBase::CreateRecv(RMsgQueueBase const*, TOwnerType)
	_ZN7CommsFW21CCFChannelPairRawBase10CreateRecvEi @ 16 NONAME ; CommsFW::CCFChannelPairRawBase::CreateRecv(int)
	_ZN7CommsFW21CCFChannelPairRawBase10CreateSendEPK13RMsgQueueBase10TOwnerType @ 17 NONAME ; CommsFW::CCFChannelPairRawBase::CreateSend(RMsgQueueBase const*, TOwnerType)
	_ZN7CommsFW21CCFChannelPairRawBase10CreateSendEi @ 18 NONAME ; CommsFW::CCFChannelPairRawBase::CreateSend(int)
	_ZN7CommsFW17RCFChannelRawBase6CreateEPK13RMsgQueueBase10TOwnerTypePS1_i @ 19 NONAME ; CommsFW::RCFChannelRawBase::Create(RMsgQueueBase const*, TOwnerType, RMsgQueueBase*, int)
	_ZN7CommsFW17RCFChannelRawBase6CreateEiiP13RMsgQueueBasei @ 20 NONAME ; CommsFW::RCFChannelRawBase::Create(int, int, RMsgQueueBase*, int)
	_ZTVN7CommsFW21MCommsTransportSenderE @ 21 NONAME
	_ZTIN7CommsFW21MCommsTransportSenderE @ 22 NONAME
	_ZN7CommsFW21CCFChannelPairRawBase8DoCancelEv @ 23 NONAME ; CommsFW::CCFChannelPairRawBase::DoCancel(void)
	_ZN7CommsFW23CCFModuleChannelHandler8DoCancelEv @ 24 NONAME ; CommsFW::CCFModuleChannelHandler::DoCancel(void)
	_ZN7CommsFW21CCFChannelPairRawBase9DoSendPIGEPKv @ 25 NONAME ; CommsFW::CCFChannelPairRawBase::DoSendPIG(void const*)
	_ZNK7CommsFW17RCFChannelRawBase12GetMsgQueuesEP13RMsgQueueBasePKS1_i @ 26 NONAME ; CommsFW::RCFChannelRawBase::GetMsgQueues(RMsgQueueBase*, RMsgQueueBase const*, int) const
	_ZNK7CommsFW21CCFChannelPairRawBase16GetRecvMsgQueuesEP13RMsgQueueBase @ 27 NONAME ; CommsFW::CCFChannelPairRawBase::GetRecvMsgQueues(RMsgQueueBase*) const
	_ZNK7CommsFW21CCFChannelPairRawBase16GetSendMsgQueuesEP13RMsgQueueBase @ 28 NONAME ; CommsFW::CCFChannelPairRawBase::GetSendMsgQueues(RMsgQueueBase*) const
	_ZN7CommsFW21CCFChannelPairRawBase8IsMsgPIGEPKv @ 29 NONAME ; CommsFW::CCFChannelPairRawBase::IsMsgPIG(void const*)
	_ZNK7CommsFW17RCFChannelRawBase6IsOpenEPK13RMsgQueueBase @ 30 NONAME ; CommsFW::RCFChannelRawBase::IsOpen(RMsgQueueBase const*) const
	_ZN7CommsFW17RCFChannelRawBase19NotifyDataAvailableER14TRequestStatusP13RMsgQueueBase @ 31 NONAME ; CommsFW::RCFChannelRawBase::NotifyDataAvailable(TRequestStatus&, RMsgQueueBase*)
	_ZN7CommsFW21CCFChannelPairRawBase19NotifyDataAvailableER14TRequestStatus @ 32 NONAME ; CommsFW::CCFChannelPairRawBase::NotifyDataAvailable(TRequestStatus&)
	_ZN7CommsFW17RCFChannelRawBase20NotifySpaceAvailableER14TRequestStatusiP13RMsgQueueBase @ 33 NONAME ; CommsFW::RCFChannelRawBase::NotifySpaceAvailable(TRequestStatus&, int, RMsgQueueBase*)
	_ZN7CommsFW21CCFChannelPairRawBase20NotifySpaceAvailableER14TRequestStatusi @ 34 NONAME ; CommsFW::CCFChannelPairRawBase::NotifySpaceAvailable(TRequestStatus&, int)
	_ZNK7CommsFW19TCFSubModuleAddress9PrintableER5TBuf8ILi65EE @ 35 NONAME ; CommsFW::TCFSubModuleAddress::Printable(TBuf8<65>&) const
	_ZN7CommsFW17RCFChannelRawBase7ReceiveEPviP13RMsgQueueBasei @ 36 NONAME ; CommsFW::RCFChannelRawBase::Receive(void*, int, RMsgQueueBase*, int)
	_ZN7CommsFW21CCFChannelPairRawBase7ReceiveEPv @ 37 NONAME ; CommsFW::CCFChannelPairRawBase::Receive(void*)
	_ZN7CommsFW21CCFChannelPairRawBase4RunLEv @ 38 NONAME ; CommsFW::CCFChannelPairRawBase::RunL(void)
	_ZN7CommsFW23CCFModuleChannelHandler4RunLEv @ 39 NONAME ; CommsFW::CCFModuleChannelHandler::RunL(void)
	_ZN7CommsFW21CCFChannelPairRawBase7SendPIGEv @ 40 NONAME ; CommsFW::CCFChannelPairRawBase::SendPIG(void)
	_ZN7CommsFW17RCFChannelRawBase4SendEPKviiP13RMsgQueueBase @ 41 NONAME ; CommsFW::RCFChannelRawBase::Send(void const*, int, int, RMsgQueueBase*)
	_ZN7CommsFW21CCFChannelPairRawBase4SendEPKvi @ 42 NONAME ; CommsFW::CCFChannelPairRawBase::Send(void const*, int)
	_ZN7CommsFW23CCFModuleChannelHandler4SendERKNS_10TCFMessageE @ 43 NONAME ; CommsFW::CCFModuleChannelHandler::Send(CommsFW::TCFMessage const&)
	_ZN7CommsFW19TCFSubModuleAddress9SetModuleERK5TBuf8ILi32EE @ 44 NONAME ; CommsFW::TCFSubModuleAddress::SetModule(TBuf8<32> const&)
	_ZN7CommsFW19TCFSubModuleAddress12SetSubModuleERK5TBuf8ILi32EE @ 45 NONAME ; CommsFW::TCFSubModuleAddress::SetSubModule(TBuf8<32> const&)
	_ZN7CommsFW17RCFChannelRawBaseD1Ev @ 46 NONAME ; CommsFW::RCFChannelRawBase::~RCFChannelRawBase(void)
	_ZN7CommsFW21CCFChannelPairRawBaseD1Ev @ 47 NONAME ; CommsFW::CCFChannelPairRawBase::~CCFChannelPairRawBase(void)
	_ZN7CommsFW23CCFModuleChannelHandlerD1Ev @ 48 NONAME ; CommsFW::CCFModuleChannelHandler::~CCFModuleChannelHandler(void)
	_ZN7CommsFW17RCFChannelRawBaseC1Ev @ 49 NONAME ; CommsFW::RCFChannelRawBase::RCFChannelRawBase(void)
	_ZN7CommsFW19TCFSubModuleAddressC1Ev @ 50 NONAME ; CommsFW::TCFSubModuleAddress::TCFSubModuleAddress(void)
	_ZN7CommsFW19TCFSubModuleAddressC1ERKS0_ @ 51 NONAME ; CommsFW::TCFSubModuleAddress::TCFSubModuleAddress(CommsFW::TCFSubModuleAddress const&)
	_ZN7CommsFW19TCFSubModuleAddressC1ERK5TBuf8ILi32EES4_ @ 52 NONAME ; CommsFW::TCFSubModuleAddress::TCFSubModuleAddress(TBuf8<32> const&, TBuf8<32> const&)
	_ZN7CommsFW21CCFChannelPairRawBaseC1EiP13RMsgQueueBaseRNS_17RCFChannelRawBaseES2_S4_ii @ 53 NONAME ; CommsFW::CCFChannelPairRawBase::CCFChannelPairRawBase(int, RMsgQueueBase*, CommsFW::RCFChannelRawBase&, RMsgQueueBase*, CommsFW::RCFChannelRawBase&, int, int)
	_ZN7CommsFW23CCFModuleChannelHandlerC1Ei @ 54 NONAME ; CommsFW::CCFModuleChannelHandler::CCFModuleChannelHandler(int)
	_ZN7CommsFW19TCFSubModuleAddressaSERKS0_ @ 55 NONAME ; CommsFW::TCFSubModuleAddress::operator=(CommsFW::TCFSubModuleAddress const&)
	_ZNK7CommsFW19TCFSubModuleAddresseqERKS0_ @ 56 NONAME ; CommsFW::TCFSubModuleAddress::operator==(CommsFW::TCFSubModuleAddress const&) const
	_ZN7CommsFW23CCFModuleChannelHandler14CFChannelErrorEi @ 57 NONAME ; CommsFW::CCFModuleChannelHandler::CFChannelError(int)
	_ZN7CommsFW21CCFChannelPairRawBaseC2EiP13RMsgQueueBaseRNS_17RCFChannelRawBaseES2_S4_ii @ 58 NONAME ; CommsFW::CCFChannelPairRawBase::CCFChannelPairRawBase[not-in-charge](int, RMsgQueueBase*, CommsFW::RCFChannelRawBase&, RMsgQueueBase*, CommsFW::RCFChannelRawBase&, int, int)
	_ZN7CommsFW23CCFModuleChannelHandlerD2Ev @ 59 NONAME ; CommsFW::CCFModuleChannelHandler::~CCFModuleChannelHandler [not-in-charge](void)
	_ZN7CommsFW19TCFSubModuleAddressC2Ev @ 60 NONAME ; CommsFW::TCFSubModuleAddress::TCFSubModuleAddress[not-in-charge](void)
	_ZN7CommsFW19TCFSubModuleAddressC2ERKS0_ @ 61 NONAME ; CommsFW::TCFSubModuleAddress::TCFSubModuleAddress[not-in-charge](CommsFW::TCFSubModuleAddress const&)
	_ZN7CommsFW23CCFModuleChannelHandlerD0Ev @ 62 NONAME ; CommsFW::CCFModuleChannelHandler::~CCFModuleChannelHandler [in-charge deleting](void)
	_ZN7CommsFW21CCFChannelPairRawBaseD0Ev @ 63 NONAME ; CommsFW::CCFChannelPairRawBase::~CCFChannelPairRawBase [in-charge deleting](void)
	_ZN7CommsFW21CCFChannelPairRawBaseD2Ev @ 64 NONAME ; CommsFW::CCFChannelPairRawBase::~CCFChannelPairRawBase [not-in-charge](void)
	_ZN7CommsFW23CCFModuleChannelHandlerC2Ei @ 65 NONAME ; CommsFW::CCFModuleChannelHandler::CCFModuleChannelHandler[not-in-charge](int)
	_ZN7CommsFW19TCFSubModuleAddressC2ERK5TBuf8ILi32EES4_ @ 66 NONAME ; CommsFW::TCFSubModuleAddress::TCFSubModuleAddress[not-in-charge](TBuf8<32> const&, TBuf8<32> const&)
	_ZN7CommsFW17RCFChannelRawBaseC2Ev @ 67 NONAME ; CommsFW::RCFChannelRawBase::RCFChannelRawBase[not-in-charge](void)
	_ZN7CommsFW17RCFChannelRawBaseD2Ev @ 68 NONAME ; CommsFW::RCFChannelRawBase::~RCFChannelRawBase [not-in-charge](void)
	_ZTIN7CommsFW21CCFChannelPairRawBaseE @ 69 NONAME ; typeinfo for CommsFW::CCFChannelPairRawBase
	_ZTIN7CommsFW23CCFModuleChannelHandlerE @ 70 NONAME ; typeinfo for CommsFW::CCFModuleChannelHandler
	_ZTVN7CommsFW21CCFChannelPairRawBaseE @ 71 NONAME ; vtable for CommsFW::CCFChannelPairRawBase
	_ZTVN7CommsFW23CCFModuleChannelHandlerE @ 72 NONAME ; vtable for CommsFW::CCFModuleChannelHandler
	_ZN7CommsFW13COwnEntryList21WildScanAcrossDrivesLERK7TDesC16S3_ @ 73 NONAME
	_ZN7CommsFW13COwnEntryList4AddLERKNS0_9TOwnEntryE @ 74 NONAME
	_ZN7CommsFW13COwnEntryList4AddLERKS0_ @ 75 NONAME
	_ZN7CommsFW13COwnEntryList9TOwnEntryC1ERK6TParseRK6TEntry @ 76 NONAME
	_ZN7CommsFW13COwnEntryList9TOwnEntryC2ERK6TParseRK6TEntry @ 77 NONAME
	_ZN7CommsFW13COwnEntryListC1Ei @ 78 NONAME
	_ZN7CommsFW13COwnEntryListC2Ei @ 79 NONAME
	_ZN7CommsFW17GetVarFromIniDataERK6TDesC8S2_S2_R6TPtrC8 @ 80 NONAME
	_ZNK7CommsFW13COwnEntryList5CountEv @ 81 NONAME
	_ZNK7CommsFW13COwnEntryListixEi @ 82 NONAME
	_ZN7CommsFW13COwnEntryListD0Ev @ 83 NONAME
	_ZN7CommsFW13COwnEntryListD1Ev @ 84 NONAME
	_ZN7CommsFW13COwnEntryListD2Ev @ 85 NONAME
	_ZTIN7CommsFW13COwnEntryListE @ 86 NONAME ; #<TI>#
	_ZTVN7CommsFW13COwnEntryListE @ 87 NONAME ; #<VT>#
	_ZN7CommsFW13RCFSharedHeap17LogAllocatedCellsERK6TDesC8S3_ @ 88 NONAME
	_ZNK7CommsFW13RCFSharedHeap11AccessCountEv @ 89 NONAME
	_ZN7CommsFW23CCFModuleChannelHandler16CFMessageForwardERKNS_13TCFForwardMsgE @ 90 NONAME
	_ZN7CommsFW13COwnEntryList27UniqueWildScanAcrossDrivesLERK7TDesC16S3_ @ 91 NONAME
	_ZNK7CommsFW15CCommsTransport8WorkerIdEv @ 92 NONAME
	_ZNK7CommsFW15CCommsTransport27LastRequestIdConcerningPeerEt @ 93 NONAME
	_ZNK7CommsFW15CCommsTransport22IsDropTransportPendingEt @ 94 NONAME
	_ZNK7CommsFW15CCommsTransport13PeerReachableEt @ 95 NONAME
	_ZN7CommsFW21TWorkerThreadDataBase4InitEti @ 96 NONAME
	_ZN7CommsFW17GetVarFromIniDataERK6TDesC8S2_S2_Ri @ 97 NONAME
	_ZN7CommsFW15CCommsTransport30SetLastRequestIdConcerningPeerEti @ 98 NONAME
	_ZN7CommsFW15CCommsTransport24EstablishTransportToPeerEtRKNS_19RCFChannelMsgQueuesES3_ @ 99 NONAME
	_ZN7CommsFW15CCommsTransport23SetDropTransportPendingEti @ 100 NONAME
	_ZN7CommsFW15CCommsTransport23RegisterLegacyInterfaceEPNS_22MLegacyMessageReceiverE @ 101 NONAME
	_ZN7CommsFW15CCommsTransport19DropTransportToPeerEt @ 102 NONAME
	_ZN7CommsFW15CCommsTransport17DeregisterAddressERN8Messages13TRuntimeCtxIdE @ 103 NONAME
	_ZN7CommsFW15CCommsTransport15SendMessageSyncERKNS_10TCFMessageE @ 104 NONAME
	_ZN7CommsFW15CCommsTransport15RegisterAddressERN8Messages13TRuntimeCtxIdE @ 105 NONAME
	_ZN7CommsFW15CCommsTransport11PostMessageERKNS_10TCFMessageE @ 106 NONAME
	_ZN7CommsFW15CCommsTransport11PostMessageERKN8Messages13TRuntimeCtxIdES4_RK6TDesC8 @ 107 NONAME
	_ZN7CommsFW15CCommsTransport11GetReceiverEv @ 108 NONAME
	_ZN7CommsFW10ConvertValERK6TDesC8Rt @ 109 NONAME
	_ZN7CommsFW15CCommsTransport4NewLERNS_21MWorkerThreadRegisterEPKN4Meta27CMetaDataVirtualCtorInPlaceEPNS_17CCFTransportHooksE @ 110 NONAME
	_ZN7CommsFW10ConvertValERK6TDesC8Rm @ 111 NONAME
	_ZN7CommsFW15CCommsTransport9GetSenderEv @ 112 NONAME
	_ZN7CommsFW16CPerfMetricStore9AddClientEPvPFiS1_R5TDes8P13TDes8OverflowE @ 113 NONAME
	_ZN7CommsFW15CCommsTransportD0Ev @ 114 NONAME
	_ZN7CommsFW15CCommsTransportD1Ev @ 115 NONAME
	_ZN7CommsFW15CCommsTransportD2Ev @ 116 NONAME
	_ZN7CommsFW16CPerfMetricStore7DestroyEv @ 117 NONAME
	_ZN7CommsFW16CPerfMetricStore4NewLEi27TTimeIntervalMicroSeconds32 @ 118 NONAME
	_ZTVN7CommsFW19CCommsTransportImplE @ 119 NONAME ; #<VT>#
	_ZTVN7CommsFW15CCommsTransportE @ 120 NONAME ; #<VT>#
	_ZTV20CTransportSelfSender @ 121 NONAME ; #<VT>#
	_ZTV17CTransportChipper @ 122 NONAME ; #<VT>#
	_ZTIN7CommsFW19CCommsTransportImplE @ 123 NONAME ; #<TI>#
	_ZTIN7CommsFW15CCommsTransportE @ 124 NONAME ; #<TI>#
	_ZTI20CTransportSelfSender @ 125 NONAME ; #<TI>#
	_ZTI17CTransportChipper @ 126 NONAME ; #<TI>#
	_ZN7CommsFW21TWorkerThreadDataBase5ClearEv @ 127 NONAME
	_ZN7CommsFW5PanicENS_18TCFTransportPanicsE @ 128 NONAME
	_ZNK7CommsFW15CCommsTransport15RegisteredCountEv @ 129 NONAME
	_ZN7CommsFW16CPerfMetricStore12RemoveClientEPv @ 130 NONAME


